Django Find My Device

# FMD Server

## Privacy Notice

### What data is stored when visiting the website?

To establish a connection, your IP address is transmitted. To prevent abuse, the IP address is logged for failed login attempts.

### What data is stored on the server?

In plaintext:

- FMD ID
- Password Hash
- Public key
- Push URL
- Unix timestamp when the client last connected

Signed:

- Command to be delivered to the phone

Encrypted:

- Private key
- If uploaded: pictures
- If uploaded: locations (lat, lon, battery level, timestamp)

Important: you need to keep your password safe! Your password is used to unlock the encrypted private key.

### How exactly does the encryption work?

Please see the description on the project website.

### Is my data transferred/sold/etc?

Your data is only used to provide the functionality of finding and controlling your device. It is not given to other parties.

### Who has access to the data?

Only the server operator has access to the database. But all important data is encrypted anyway.

### How can I delete my data from the server?

You can delete your account using the "Delete Account" button in the web interface and in the Android app.

### How can I export my data?

Log in via the web interface, click on the settings icon, and then click on "Export Data". This will fetch all data from the server, decrypt it locally, and locally create a ZIP file that you can save to your computer.

### How can I change my password?

You can change your password in the FMD Android app in the FMD Server settings section.

### How can I reset my password?

You cannot reset your password, only change it. The server administrator cannot reset or change your password. They can only delete your account entirely (allowing you to register again). However, since this is destructive, the server administrator should only do so if they can verify that this account really belongs to you.